@@ -213,29 +213,37 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#close)
+        """
+
     def create_project(
         self,
         *,
         name: str,
-        source: "ProjectSourceTypeDef",
-        artifacts: "ProjectArtifactsTypeDef",
-        environment: "ProjectEnvironmentTypeDef",
+        source: ProjectSourceTypeDef,
+        artifacts: ProjectArtifactsTypeDef,
+        environment: ProjectEnvironmentTypeDef,
         serviceRole: str,
         description: str = ...,
-        secondarySources: Sequence["ProjectSourceTypeDef"] = ...,
+        secondarySources: Sequence[ProjectSourceTypeDef] = ...,
         sourceVersion: str = ...,
-        secondarySourceVersions: Sequence["ProjectSourceVersionTypeDef"] = ...,
-        secondaryArtifacts: Sequence["ProjectArtifactsTypeDef"] = ...,
-        cache: "ProjectCacheTypeDef" = ...,
+        secondarySourceVersions: Sequence[ProjectSourceVersionTypeDef] = ...,
+        secondaryArtifacts: Sequence[ProjectArtifactsTypeDef] = ...,
+        cache: ProjectCacheTypeDef = ...,
         timeoutInMinutes: int = ...,
         queuedTimeoutInMinutes: int = ...,
         encryptionKey: str = ...,
-        tags: Sequence["TagTypeDef"] = ...,
-        vpcConfig: "VpcConfigTypeDef" = ...,
+        tags: Sequence[TagTypeDef] = ...,
+        vpcConfig: VpcConfigTypeDef = ...,
         badgeEnabled: bool = ...,
-        logsConfig: "LogsConfigTypeDef" = ...,
-        fileSystemLocations: Sequence["ProjectFileSystemLocationTypeDef"] = ...,
-        buildBatchConfig: "ProjectBuildBatchConfigTypeDef" = ...,
+        logsConfig: LogsConfigTypeDef = ...,
+        fileSystemLocations: Sequence[ProjectFileSystemLocationTypeDef] = ...,
+        buildBatchConfig: ProjectBuildBatchConfigTypeDef = ...,
         concurrentBuildLimit: int = ...
     ) -> CreateProjectOutputTypeDef:
         """
@@ -250,8 +258,8 @@ class CodeBuildClient(BaseClient):
         *,
         name: str,
         type: ReportTypeType,
-        exportConfig: "ReportExportConfigTypeDef",
-        tags: Sequence["TagTypeDef"] = ...
+        exportConfig: ReportExportConfigTypeDef,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateReportGroupOutputTypeDef:
         """
         Creates a report group.
@@ -265,7 +273,7 @@ class CodeBuildClient(BaseClient):
         *,
         projectName: str,
         branchFilter: str = ...,
-        filterGroups: Sequence[Sequence["WebhookFilterTypeDef"]] = ...,
+        filterGroups: Sequence[Sequence[WebhookFilterTypeDef]] = ...,
         buildType: WebhookBuildTypeType = ...
     ) -> CreateWebhookOutputTypeDef:
         """
@@ -359,7 +367,7 @@ class CodeBuildClient(BaseClient):
         reportArn: str,
         nextToken: str = ...,
         maxResults: int = ...,
-        filter: "TestCaseFilterTypeDef" = ...
+        filter: TestCaseFilterTypeDef = ...
     ) -> DescribeTestCasesOutputTypeDef:
         """
         Returns a list of details about test cases for a report.
@@ -432,7 +440,7 @@ class CodeBuildClient(BaseClient):
     def list_build_batches(
         self,
         *,
-        filter: "BuildBatchFilterTypeDef" = ...,
+        filter: BuildBatchFilterTypeDef = ...,
         maxResults: int = ...,
         sortOrder: SortOrderTypeType = ...,
         nextToken: str = ...
@@ -448,7 +456,7 @@ class CodeBuildClient(BaseClient):
         self,
         *,
         projectName: str = ...,
-        filter: "BuildBatchFilterTypeDef" = ...,
+        filter: BuildBatchFilterTypeDef = ...,
         maxResults: int = ...,
         sortOrder: SortOrderTypeType = ...,
         nextToken: str = ...
@@ -526,7 +534,7 @@ class CodeBuildClient(BaseClient):
         sortOrder: SortOrderTypeType = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filter: "ReportFilterTypeDef" = ...
+        filter: ReportFilterTypeDef = ...
     ) -> ListReportsOutputTypeDef:
         """
         Returns a list of ARNs for the reports in the current Amazon Web Services
@@ -543,7 +551,7 @@ class CodeBuildClient(BaseClient):
         nextToken: str = ...,
         sortOrder: SortOrderTypeType = ...,
         maxResults: int = ...,
-        filter: "ReportFilterTypeDef" = ...
+        filter: ReportFilterTypeDef = ...
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
         Returns a list of ARNs for the reports that belong to a `ReportGroup` .
@@ -628,34 +636,34 @@ class CodeBuildClient(BaseClient):
         self,
         *,
         projectName: str,
-        secondarySourcesOverride: Sequence["ProjectSourceTypeDef"] = ...,
-        secondarySourcesVersionOverride: Sequence["ProjectSourceVersionTypeDef"] = ...,
+        secondarySourcesOverride: Sequence[ProjectSourceTypeDef] = ...,
+        secondarySourcesVersionOverride: Sequence[ProjectSourceVersionTypeDef] = ...,
         sourceVersion: str = ...,
-        artifactsOverride: "ProjectArtifactsTypeDef" = ...,
-        secondaryArtifactsOverride: Sequence["ProjectArtifactsTypeDef"] = ...,
-        environmentVariablesOverride: Sequence["EnvironmentVariableTypeDef"] = ...,
+        artifactsOverride: ProjectArtifactsTypeDef = ...,
+        secondaryArtifactsOverride: Sequence[ProjectArtifactsTypeDef] = ...,
+        environmentVariablesOverride: Sequence[EnvironmentVariableTypeDef] = ...,
         sourceTypeOverride: SourceTypeType = ...,
         sourceLocationOverride: str = ...,
-        sourceAuthOverride: "SourceAuthTypeDef" = ...,
+        sourceAuthOverride: SourceAuthTypeDef = ...,
         gitCloneDepthOverride: int = ...,
-        gitSubmodulesConfigOverride: "GitSubmodulesConfigTypeDef" = ...,
+        gitSubmodulesConfigOverride: GitSubmodulesConfigTypeDef = ...,
         buildspecOverride: str = ...,
         insecureSslOverride: bool = ...,
         reportBuildStatusOverride: bool = ...,
-        buildStatusConfigOverride: "BuildStatusConfigTypeDef" = ...,
+        buildStatusConfigOverride: BuildStatusConfigTypeDef = ...,
         environmentTypeOverride: EnvironmentTypeType = ...,
         imageOverride: str = ...,
         computeTypeOverride: ComputeTypeType = ...,
         certificateOverride: str = ...,
-        cacheOverride: "ProjectCacheTypeDef" = ...,
+        cacheOverride: ProjectCacheTypeDef = ...,
         serviceRoleOverride: str = ...,
         privilegedModeOverride: bool = ...,
         timeoutInMinutesOverride: int = ...,
         queuedTimeoutInMinutesOverride: int = ...,
         encryptionKeyOverride: str = ...,
         idempotencyToken: str = ...,
-        logsConfigOverride: "LogsConfigTypeDef" = ...,
-        registryCredentialOverride: "RegistryCredentialTypeDef" = ...,
+        logsConfigOverride: LogsConfigTypeDef = ...,
+        registryCredentialOverride: RegistryCredentialTypeDef = ...,
         imagePullCredentialsTypeOverride: ImagePullCredentialsTypeType = ...,
         debugSessionEnabled: bool = ...
     ) -> StartBuildOutputTypeDef:
@@ -670,17 +678,17 @@ class CodeBuildClient(BaseClient):
         self,
         *,
         projectName: str,
-        secondarySourcesOverride: Sequence["ProjectSourceTypeDef"] = ...,
-        secondarySourcesVersionOverride: Sequence["ProjectSourceVersionTypeDef"] = ...,
+        secondarySourcesOverride: Sequence[ProjectSourceTypeDef] = ...,
+        secondarySourcesVersionOverride: Sequence[ProjectSourceVersionTypeDef] = ...,
         sourceVersion: str = ...,
-        artifactsOverride: "ProjectArtifactsTypeDef" = ...,
-        secondaryArtifactsOverride: Sequence["ProjectArtifactsTypeDef"] = ...,
-        environmentVariablesOverride: Sequence["EnvironmentVariableTypeDef"] = ...,
+        artifactsOverride: ProjectArtifactsTypeDef = ...,
+        secondaryArtifactsOverride: Sequence[ProjectArtifactsTypeDef] = ...,
+        environmentVariablesOverride: Sequence[EnvironmentVariableTypeDef] = ...,
         sourceTypeOverride: SourceTypeType = ...,
         sourceLocationOverride: str = ...,
-        sourceAuthOverride: "SourceAuthTypeDef" = ...,
+        sourceAuthOverride: SourceAuthTypeDef = ...,
         gitCloneDepthOverride: int = ...,
-        gitSubmodulesConfigOverride: "GitSubmodulesConfigTypeDef" = ...,
+        gitSubmodulesConfigOverride: GitSubmodulesConfigTypeDef = ...,
         buildspecOverride: str = ...,
         insecureSslOverride: bool = ...,
         reportBuildBatchStatusOverride: bool = ...,
@@ -688,17 +696,17 @@ class CodeBuildClient(BaseClient):
         imageOverride: str = ...,
         computeTypeOverride: ComputeTypeType = ...,
         certificateOverride: str = ...,
-        cacheOverride: "ProjectCacheTypeDef" = ...,
+        cacheOverride: ProjectCacheTypeDef = ...,
         serviceRoleOverride: str = ...,
         privilegedModeOverride: bool = ...,
         buildTimeoutInMinutesOverride: int = ...,
         queuedTimeoutInMinutesOverride: int = ...,
         encryptionKeyOverride: str = ...,
         idempotencyToken: str = ...,
-        logsConfigOverride: "LogsConfigTypeDef" = ...,
-        registryCredentialOverride: "RegistryCredentialTypeDef" = ...,
+        logsConfigOverride: LogsConfigTypeDef = ...,
+        registryCredentialOverride: RegistryCredentialTypeDef = ...,
         imagePullCredentialsTypeOverride: ImagePullCredentialsTypeType = ...,
-        buildBatchConfigOverride: "ProjectBuildBatchConfigTypeDef" = ...,
+        buildBatchConfigOverride: ProjectBuildBatchConfigTypeDef = ...,
         debugSessionEnabled: bool = ...
     ) -> StartBuildBatchOutputTypeDef:
         """
@@ -729,24 +737,24 @@ class CodeBuildClient(BaseClient):
         *,
         name: str,
         description: str = ...,
-        source: "ProjectSourceTypeDef" = ...,
-        secondarySources: Sequence["ProjectSourceTypeDef"] = ...,
+        source: ProjectSourceTypeDef = ...,
+        secondarySources: Sequence[ProjectSourceTypeDef] = ...,
         sourceVersion: str = ...,
-        secondarySourceVersions: Sequence["ProjectSourceVersionTypeDef"] = ...,
-        artifacts: "ProjectArtifactsTypeDef" = ...,
-        secondaryArtifacts: Sequence["ProjectArtifactsTypeDef"] = ...,
-        cache: "ProjectCacheTypeDef" = ...,
-        environment: "ProjectEnvironmentTypeDef" = ...,
+        secondarySourceVersions: Sequence[ProjectSourceVersionTypeDef] = ...,
+        artifacts: ProjectArtifactsTypeDef = ...,
+        secondaryArtifacts: Sequence[ProjectArtifactsTypeDef] = ...,
+        cache: ProjectCacheTypeDef = ...,
+        environment: ProjectEnvironmentTypeDef = ...,
         serviceRole: str = ...,
         timeoutInMinutes: int = ...,
         queuedTimeoutInMinutes: int = ...,
         encryptionKey: str = ...,
-        tags: Sequence["TagTypeDef"] = ...,
-        vpcConfig: "VpcConfigTypeDef" = ...,
+        tags: Sequence[TagTypeDef] = ...,
+        vpcConfig: VpcConfigTypeDef = ...,
         badgeEnabled: bool = ...,
-        logsConfig: "LogsConfigTypeDef" = ...,
-        fileSystemLocations: Sequence["ProjectFileSystemLocationTypeDef"] = ...,
-        buildBatchConfig: "ProjectBuildBatchConfigTypeDef" = ...,
+        logsConfig: LogsConfigTypeDef = ...,
+        fileSystemLocations: Sequence[ProjectFileSystemLocationTypeDef] = ...,
+        buildBatchConfig: ProjectBuildBatchConfigTypeDef = ...,
         concurrentBuildLimit: int = ...
     ) -> UpdateProjectOutputTypeDef:
         """
@@ -774,8 +782,8 @@ class CodeBuildClient(BaseClient):
         self,
         *,
         arn: str,
-        exportConfig: "ReportExportConfigTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        exportConfig: ReportExportConfigTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> UpdateReportGroupOutputTypeDef:
         """
         Updates a report group.
@@ -790,7 +798,7 @@ class CodeBuildClient(BaseClient):
         projectName: str,
         branchFilter: str = ...,
         rotateSecret: bool = ...,
-        filterGroups: Sequence[Sequence["WebhookFilterTypeDef"]] = ...,
+        filterGroups: Sequence[Sequence[WebhookFilterTypeDef]] = ...,
         buildType: WebhookBuildTypeType = ...
     ) -> UpdateWebhookOutputTypeDef:
         """
